GroupElement

Struct GroupElement 

pub struct GroupElement(/* private fields */);
Element on a group.

Cannot be converted to a scalar. Supports addition and subtraction. Multiplication by a scalar is supported. We use ristretto points to discard unsafe points and safely use the group operations in higher level protocols without any other cryptographic assumptions.

Implementations

Source

impl GroupElement

pub fn random<R: Rng + CryptoRng>(rng: &mut R) -> Self

Generate a random GroupElement. This is the preferred way of generating pseudonyms.

pub fn from_bytes(v: &[u8; 32]) -> Option<Self>

Create from a 32-byte compressed Ristretto point.

Returns None if the point is not valid (only ~6.25% of all 32-byte strings are valid encodings, use lizard technique to decode arbitrary data).

Curve25519 has exactly 2^255 - 19 points. Ristretto removes the cofactor 8 and maps the points to a subgroup of prime order 2^252 + 27742317777372353535851937790883648493 (the Elligator mapping takes 253 bits).

pub fn from_slice(v: &[u8]) -> Option<Self>

Create from a byte slice.

pub fn to_bytes(&self) -> [u8; 32]

Convert to a 32-byte array.

Any GroupElement can be converted this way.

pub fn from_hash(v: &[u8; 64]) -> Self

Create from a 64-byte hash.

This is a one-way function. Multiple hashes can map to the same point.

pub fn from_lizard(v: &[u8; 16]) -> Self

Create from any 16-byte string bijectively, using the lizard approach.

There are practically no invalid lizard encodings! This is useful to encode arbitrary data as group element.

pub fn to_lizard(&self) -> Option<[u8; 16]>

Convert to a 16-byte string using the lizard approach.

Notice that a Ristretto point is represented as 32 bytes with ~2^252 valid points, so only a very small fraction of points (only those created from lizard) can be converted this way.

pub fn from_hex(s: &str) -> Option<Self>

Create from a hexadecimal string (32 bytes or 64 characters).

Returns None if the string is not a valid hexadecimal encoding of a Ristretto point.

pub fn to_hex(&self) -> String

Convert to a hexadecimal string.

pub fn identity() -> Self

Return the identity element of the group.