Module data

Module data 

Modules

json
JSON value types that can be encrypted using PEP cryptography.
long
Long (multi-block) data types for pseudonyms and attributes.
padding
Padding mechanisms for PEP data encoding.
records
Record types for encrypting multiple pseudonyms and attributes together.
simple
Core data types for pseudonyms and attributes, their encrypted versions, and session-key based encryption and decryption operations.
traits
Core traits for encryption and decryption operations.