Attribute

Struct Attribute 

pub struct Attribute {
    pub value: GroupElement,
}
An attribute (in the background, this is a GroupElement), which should not be identifiable and can be encrypted and rekeyed, but not reshuffled.

Fields

value: GroupElement

Methods from Deref<Target = GroupElement>

pub fn to_bytes(&self) -> [u8; 32]

Convert to a 32-byte array.

Any GroupElement can be converted this way.

pub fn to_lizard(&self) -> Option<[u8; 16]>

Convert to a 16-byte string using the lizard approach.

Notice that a Ristretto point is represented as 32 bytes with ~2^252 valid points, so only a very small fraction of points (only those created from lizard) can be converted this way.

pub fn to_hex(&self) -> String

Convert to a hexadecimal string.