pub enum EncryptionContext {
Global,
Specific(String),
}Expand description
Encryption contexts are used to describe the context in which ciphertexts exist (typically, a user’s session).
With the offline feature enabled, contexts can be Global (for offline encryption).
With the legacy feature enabled, specific contexts include an audience_type field.
Variants
Implementations