Secret

Type Alias Secret 

pub type Secret = Box<[u8]>;
A secret is a byte array of arbitrary length, which is used to derive pseudonymization and rekeying factors from contexts.

Aliased Type

pub struct Secret(/* private fields */);