pub struct TranscryptionInfo {
pub pseudonym: PseudonymizationInfo,
pub attribute: AttributeRekeyInfo,
}Expand description
The information required for transcryption, containing both pseudonymization info and attribute rekey info.
Fields
pseudonym: PseudonymizationInfoattribute: AttributeRekeyInfoImplementations
Sourceimpl TranscryptionInfo
impl TranscryptionInfo
Sourcepub fn new(
domain_from: &PseudonymizationDomain,
domain_to: &PseudonymizationDomain,
session_from: &EncryptionContext,
session_to: &EncryptionContext,
pseudonymization_secret: &PseudonymizationSecret,
encryption_secret: &EncryptionSecret,
) -> Self
pub fn new( domain_from: &PseudonymizationDomain, domain_to: &PseudonymizationDomain, session_from: &EncryptionContext, session_to: &EncryptionContext, pseudonymization_secret: &PseudonymizationSecret, encryption_secret: &EncryptionSecret, ) -> Self
Compute the transcryption info given pseudonymization domains, sessions and secrets.