SecretKey

Trait SecretKey 

pub trait SecretKey {
    // Required method
    fn value(&self) -> &ScalarNonZero;
}
A trait for secret keys, for which we do not allow encoding as secret keys should not be shared.

Required Methods

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors