pub struct GroupElement(/* private fields */);Expand description
Element on a group.
Cannot be converted to a scalar. Supports addition and subtraction. Multiplication by a scalar is supported. We use ristretto points to discard unsafe points and safely use the group operations in higher level protocols without any other cryptographic assumptions.
Implementations
Sourceimpl GroupElement
impl GroupElement
Sourcepub fn random<R: Rng + CryptoRng>(rng: &mut R) -> Self
pub fn random<R: Rng + CryptoRng>(rng: &mut R) -> Self
Generate a random GroupElement. This is the preferred way of generating pseudonyms.
Sourcepub fn from_bytes(v: &[u8; 32]) -> Option<Self>
pub fn from_bytes(v: &[u8; 32]) -> Option<Self>
Create from a 32-byte compressed Ristretto point.
Returns None if the point is not valid (only ~6.25% of all 32-byte strings are valid
encodings, use lizard technique to decode arbitrary data).
Curve25519 has exactly 2^255 - 19 points. Ristretto removes the cofactor 8 and maps the points to a subgroup of prime order 2^252 + 27742317777372353535851937790883648493 (the Elligator mapping takes 253 bits).
Sourcepub fn from_slice(v: &[u8]) -> Option<Self>
pub fn from_slice(v: &[u8]) -> Option<Self>
Create from a byte slice.
Sourcepub fn to_bytes(&self) -> [u8; 32]
pub fn to_bytes(&self) -> [u8; 32]
Convert to a 32-byte array.
Any GroupElement can be converted this way.
Sourcepub fn from_hash(v: &[u8; 64]) -> Self
pub fn from_hash(v: &[u8; 64]) -> Self
Create from a 64-byte hash.
This is a one-way function. Multiple hashes can map to the same point.
Sourcepub fn from_lizard(v: &[u8; 16]) -> Self
pub fn from_lizard(v: &[u8; 16]) -> Self
Create from any 16-byte string bijectively, using the lizard approach.
There are practically no invalid lizard encodings! This is useful to encode arbitrary data as group element.
Sourcepub fn to_lizard(&self) -> Option<[u8; 16]>
pub fn to_lizard(&self) -> Option<[u8; 16]>
Convert to a 16-byte string using the lizard approach.
Notice that a Ristretto point is represented as 32 bytes with ~2^252 valid points, so only a very small fraction of points (only those created from lizard) can be converted this way.